@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.78 2005/07/10 19:03:37 mbarbon Exp $
+## RCS-ID:      $Id: Wx.pm,v 1.82 2005/10/25 20:59:02 mbarbon Exp $
 ## Copyright:   (c) 2000-2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.25';
+$VERSION = '0.26';
 
 sub BEGIN{
   @EXPORT_OK = qw(wxPOINT wxSIZE wxTheApp);
@@ -110,6 +110,7 @@ sub load_dll {
     foreach ( @INC ) {
       if( -f "$_/auto/Wx/Wx.dll" ) {
         $wx_path = "$_/auto/Wx";
+        $wx_path =~ s/ /\\ /g ;
         my $lib = ( glob "$wx_path/wx*${suff}_html*.dll" )[0];
         next unless $lib;
         $lib =~ s{.*[/\\]([^/\\]+)$}{$1};
@@ -219,12 +220,16 @@ package Wx::TreeItemId;
 
 use overload '<=>'      => \&tiid_spaceship,
              'bool'     => sub { $_[0]->IsOk },
+             '""'       => sub { $_[0] },
+             '0+'       => sub { $_[0] },
              'fallback' => 1;
 
 package Wx::Font;
 
 use overload '<=>'      => \&font_spaceship,
              'bool'     => sub { $_[0]->Ok },
+             '""'       => sub { $_[0] },
+             '0+'       => sub { $_[0] },
              'fallback' => 1;
 
 #
